@@ -1,4 +1,4 @@
-from cvzone.Utils import stackImages, cornerRect, findContours
+from cvzone.Utils import stackImages, cornerRect, findContours, overlayPNG, rotateImage
 from cvzone.ColorModule import ColorFinder
 from cvzone.FPS import FPS
 from cvzone.PIDModule import PID
